@@ -1,13 +1,12 @@
 package Net::Google::Analytics::Feed;
-our $VERSION = '0.10000';
+our $VERSION = '0.10001';
 use strict;
 
 use base qw(Class::Accessor Net::Google::Analytics::XML);
 
+use Scalar::Util;
 use URI;
 
-__PACKAGE__->mk_accessors(qw(_analytics));
-
 sub _uri {
     my ($self, $req, $start_index, $max_results) = @_;
 
@@ -25,6 +24,19 @@ sub _uri {
     return $uri;
 }
 
+sub _analytics {
+    my $self = $_[0];
+
+    my $analytics = $self->{_analytics};
+
+    if (@_ > 1) {
+        $self->{_analytics} = $_[1];
+        Scalar::Util::weaken($self->{_analytics});
+    }
+
+    return $analytics;
+}
+
 sub uri {
     my ($self, $req);
 
@@ -40,7 +52,7 @@ sub _retrieve_xml {
         $self->_analytics->auth_params,
     );
 
-    if(!$page_res->is_success) {
+    if (!$page_res->is_success) {
         my $status = $page_res->status_line;
         die("Analytics API request failed: $status\n");
     }
@@ -93,7 +105,7 @@ sub retrieve_paged {
     my $max_items_per_page = $self->_max_items_per_page;
     my $res;
 
-    while(!defined($remaining_items) || $remaining_items > 0) {
+    while (!defined($remaining_items) || $remaining_items > 0) {
         my $max_results =
             defined($remaining_items) &&
             $remaining_items < $max_items_per_page ?
@@ -101,7 +113,7 @@ sub retrieve_paged {
 
         my $page = $self->_retrieve($req, $start_index, $max_results);
 
-        if(!defined($res)) {
+        if (!defined($res)) {
             $res = $page;
         }
         else {
@@ -134,7 +146,7 @@ This is a base class for the feeds of the Google Analytics Data Export API.
 Account feeds are implemented in L<Net::Google::Analytics::AccountFeed>.
 Data feeds are implemented in L<Net::Google::Analytics::DataFeed>.
 
-See <http://code.google.com/apis/analytics/docs/gdata/gdataReference.html>.
+See L<http://code.google.com/apis/analytics/docs/gdata/gdataReference.html>.
 
 =head1 METHODS
 
